@@ -1,6 +1,6 @@
 from interactions.base import __version__ as __lib_version__
 
-__version__ = "2.0.5"
+__version__ = "2.1.1"
 __ext_version__ = f"{__lib_version__}:{__version__}"
 
 from . import *
@@ -8,4 +8,4 @@ from . import *
 from .callback import *
 from .subcomand import *
 from .components import *
-from .setup import *
+from .extension import *
